==> mono_6.8.0.105+dfsg.orig.tar.xz: mono-6.8.0.105+dfsg/external/binary-reference-assemblies/src/v4.5/CustomMarshalers.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

[assembly:System.Reflection.AssemblyVersionAttribute("4.0.0.0")]
[assembly:System.CLSCompliantAttribute(true)]
[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(258))]
[assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
[assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
[assembly:System.Reflection.AssemblyDefaultAliasAttribute("CustomMarshalers.dll")]
[assembly:System.Reflection.AssemblyDescriptionAttribute("CustomMarshalers.dll")]
[assembly:System.Reflection.AssemblyFileVersionAttribute("4.0.30319.17020")]
[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.0.30319.17020")]
[assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
[assembly:System.Reflection.AssemblyTitleAttribute("CustomMarshalers.dll")]
[assembly:System.Resources.NeutralResourcesLanguageAttribute("en-US")]
[assembly:System.Resources.SatelliteContractVersionAttribute("4.0.0.0")]
[assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
[assembly:System.Runtime.CompilerServices.RuntimeCompatibilityAttribute(WrapNonExceptionThrows=true)]
[assembly:System.Runtime.InteropServices.ComVisibleAttribute(false)]
namespace System
{
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoDocumentationNoteAttribute : System.MonoTODOAttribute
    {
        public MonoDocumentationNoteAttribute(string comment) { }
    }
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoExtensionAttribute : System.MonoTODOAttribute
    {
        public MonoExtensionAttribute(string comment) { }
    }
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoInternalNoteAttribute : System.MonoTODOAttribute
    {
        public MonoInternalNoteAttribute(string comment) { }
    }
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoLimitationAttribute : System.MonoTODOAttribute
    {
        public MonoLimitationAttribute(string comment) { }
    }
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoNotSupportedAttribute : System.MonoTODOAttribute
    {
        public MonoNotSupportedAttribute(string comment) { }
    }
    [System.AttributeUsageAttribute((System.AttributeTargets)(32767), AllowMultiple=true)]
    internal partial class MonoTODOAttribute : System.Attribute
    {
        public MonoTODOAttribute() { }
        public MonoTODOAttribute(string comment) { }
        public string Comment { get { throw null; } }
    }
}
namespace System.Runtime.InteropServices.CustomMarshalers
{
    public partial class EnumerableToDispatchMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal EnumerableToDispatchMarshaler() { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpManagedData(object pManagedObj) { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        [System.MonoTODOAttribute]
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        [System.MonoTODOAttribute]
        public virtual int GetNativeDataSize() { throw null; }
        [System.MonoTODOAttribute]
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        [System.MonoTODOAttribute]
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class EnumeratorToEnumVariantMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal EnumeratorToEnumVariantMarshaler() { }
        public virtual void CleanUpManagedData(object pManagedObj) { }
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        public virtual int GetNativeDataSize() { throw null; }
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class ExpandoToDispatchExMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal ExpandoToDispatchExMarshaler() { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpManagedData(object pManagedObj) { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        [System.MonoTODOAttribute]
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        [System.MonoTODOAttribute]
        public virtual int GetNativeDataSize() { throw null; }
        [System.MonoTODOAttribute]
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        [System.MonoTODOAttribute]
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class TypeToTypeInfoMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal TypeToTypeInfoMarshaler() { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpManagedData(object pManagedObj) { }
        [System.MonoTODOAttribute]
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        [System.MonoTODOAttribute]
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        [System.MonoTODOAttribute]
        public virtual int GetNativeDataSize() { throw null; }
        [System.MonoTODOAttribute]
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        [System.MonoTODOAttribute]
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
}

==> mono_6.12.0.199+dfsg.orig.tar.xz: mono-6.12.0.199+dfsg/external/binary-reference-assemblies/src/v4.7/CustomMarshalers.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

[assembly:System.Reflection.AssemblyVersionAttribute("4.0.0.0")]
[assembly:System.CLSCompliantAttribute(true)]
[assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
[assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
[assembly:System.Reflection.AssemblyDefaultAliasAttribute("CustomMarshalers.dll")]
[assembly:System.Reflection.AssemblyDescriptionAttribute("CustomMarshalers.dll")]
[assembly:System.Reflection.AssemblyFileVersionAttribute("4.7.2046.0")]
[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.7.2046.0")]
[assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
[assembly:System.Reflection.AssemblyTitleAttribute("CustomMarshalers.dll")]
[assembly:System.Resources.NeutralResourcesLanguageAttribute("en-US")]
[assembly:System.Resources.SatelliteContractVersionAttribute("4.0.0.0")]
[assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
[assembly:System.Runtime.CompilerServices.RuntimeCompatibilityAttribute(WrapNonExceptionThrows=true)]
[assembly:System.Runtime.InteropServices.ComVisibleAttribute(false)]
[assembly:System.Security.SecurityRulesAttribute((System.Security.SecurityRuleSet)(1))]
[assembly:System.Security.Permissions.SecurityPermissionAttribute(System.Security.Permissions.SecurityAction.RequestMinimum, SkipVerification=true)]
namespace System.Runtime.InteropServices.CustomMarshalers
{
    public partial class EnumerableToDispatchMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal EnumerableToDispatchMarshaler() { }
        public virtual void CleanUpManagedData(object pManagedObj) { }
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        public virtual int GetNativeDataSize() { throw null; }
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class EnumeratorToEnumVariantMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal EnumeratorToEnumVariantMarshaler() { }
        public virtual void CleanUpManagedData(object pManagedObj) { }
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        public virtual int GetNativeDataSize() { throw null; }
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class ExpandoToDispatchExMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal ExpandoToDispatchExMarshaler() { }
        public virtual void CleanUpManagedData(object pManagedObj) { }
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        public virtual int GetNativeDataSize() { throw null; }
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
    public partial class TypeToTypeInfoMarshaler : System.Runtime.InteropServices.ICustomMarshaler
    {
        internal TypeToTypeInfoMarshaler() { }
        public virtual void CleanUpManagedData(object pManagedObj) { }
        public virtual void CleanUpNativeData(System.IntPtr pNativeData) { }
        public static System.Runtime.InteropServices.ICustomMarshaler GetInstance(string pstrCookie) { throw null; }
        public virtual int GetNativeDataSize() { throw null; }
        public virtual System.IntPtr MarshalManagedToNative(object pManagedObj) { throw null; }
        public virtual object MarshalNativeToManaged(System.IntPtr pNativeData) { throw null; }
    }
}
